@@ -1,5 +1,21 @@
 #!/usr/bin/python
 # -*- coding: utf8 -*-
+"""
+    tentacles, python ORM
+    Copyright (C) 2010-2011, Guillaume Bour <guillaume@bour.cc>
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, version 3.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""
 """
 	The power of superheros !!!
 
